@@ -117,7 +117,71 @@ class TestModelClassFunction(BaseCassEngTestCase):
         """
         Test that metadata defined in one class, is not inherited by subclasses
         """
-        
+
+    def test_partition_keys(self):
+        """
+        Test compound partition key definition
+        """
+        class ModelWithPartitionKeys(cqlengine.Model):
+            c1 = cqlengine.Text(primary_key=True)
+            p1 = cqlengine.Text(partition_key=True)
+            p2 = cqlengine.Text(partition_key=True)
+
+        cols = ModelWithPartitionKeys._columns
+
+        self.assertTrue(cols['c1'].primary_key)
+        self.assertFalse(cols['c1'].partition_key)
+
+        self.assertTrue(cols['p1'].primary_key)
+        self.assertTrue(cols['p1'].partition_key)
+        self.assertTrue(cols['p2'].primary_key)
+        self.assertTrue(cols['p2'].partition_key)
+
+        obj = ModelWithPartitionKeys(p1='a', p2='b')
+        self.assertEquals(obj.pk, ('a', 'b'))
+
+    def test_del_attribute_is_assigned_properly(self):
+        """ Tests that columns that can be deleted have the del attribute """
+        class DelModel(Model):
+            key = columns.Integer(primary_key=True)
+            data = columns.Integer(required=False)
+
+        model = DelModel(key=4, data=5)
+        del model.data
+        with self.assertRaises(AttributeError):
+            del model.key
+
+    def test_does_not_exist_exceptions_are_not_shared_between_model(self):
+        """ Tests that DoesNotExist exceptions are not the same exception between models """
+
+        class Model1(Model):
+            pass
+        class Model2(Model):
+            pass
+
+        try:
+            raise Model1.DoesNotExist
+        except Model2.DoesNotExist:
+            assert False, "Model1 exception should not be caught by Model2"
+        except Model1.DoesNotExist:
+            #expected
+            pass
+
+    def test_does_not_exist_inherits_from_superclass(self):
+        """ Tests that a DoesNotExist exception can be caught by it's parent class DoesNotExist """
+        class Model1(Model):
+            pass
+        class Model2(Model1):
+            pass
+
+        try:
+            raise Model2.DoesNotExist
+        except Model1.DoesNotExist:
+            #expected
+            pass
+        except Exception:
+            assert False, "Model2 exception should not be caught by Model1"
+
 class TestManualTableNaming(BaseCassEngTestCase):
     
     class RenamedTest(cqlengine.Model):
